==> formant-1.133.63-py2.py3-none-any.whl: formant/sdk/cloud/v2/formant_admin_api_client/api/email_configuration/email_configuration_controller_post.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ...client import AuthenticatedClient
from ...models.email_configuration import EmailConfiguration
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    json_body: EmailConfiguration,
) -> Dict[str, Any]:
    url = "{}/email-configuration".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[EmailConfiguration]:
    if response.status_code == HTTPStatus.OK:
        response_200 = EmailConfiguration.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[EmailConfiguration]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: EmailConfiguration,
) -> Response[EmailConfiguration]:
    """Post

     Create a custom email configuration for the organization
    Resource: organization
    Authorized roles: administrator

    Args:
        json_body (EmailConfiguration):

    Returns:
        Response[EmailConfiguration]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    json_body: EmailConfiguration,
) -> Optional[EmailConfiguration]:
    """Post

     Create a custom email configuration for the organization
    Resource: organization
    Authorized roles: administrator

    Args:
        json_body (EmailConfiguration):

    Returns:
        Response[EmailConfiguration]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: EmailConfiguration,
) -> Response[EmailConfiguration]:
    """Post

     Create a custom email configuration for the organization
    Resource: organization
    Authorized roles: administrator

    Args:
        json_body (EmailConfiguration):

    Returns:
        Response[EmailConfiguration]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: EmailConfiguration,
) -> Optional[EmailConfiguration]:
    """Post

     Create a custom email configuration for the organization
    Resource: organization
    Authorized roles: administrator

    Args:
        json_body (EmailConfiguration):

    Returns:
        Response[EmailConfiguration]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed

==> formant-1.230.2-py2.py3-none-any.whl: formant/sdk/cloud/v2/formant_admin_api_client/api/email_configuration/email_configuration_controller_post.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ...client import AuthenticatedClient
from ...models.email_configuration import EmailConfiguration
from ...types import Response


def _get_kwargs(
    *,
    client: AuthenticatedClient,
    json_body: EmailConfiguration,
) -> Dict[str, Any]:
    url = "{}/email-configuration".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[EmailConfiguration]:
    if response.status_code == HTTPStatus.CREATED:
        response_201 = EmailConfiguration.from_dict(response.json())

        return response_201
    return None


def _build_response(*, response: httpx.Response) -> Response[EmailConfiguration]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    json_body: EmailConfiguration,
) -> Response[EmailConfiguration]:
    """Post

     Create a custom email configuration for the organization
    Resource: organization
    Authorized roles: administrator

    Args:
        json_body (EmailConfiguration):

    Returns:
        Response[EmailConfiguration]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: AuthenticatedClient,
    json_body: EmailConfiguration,
) -> Optional[EmailConfiguration]:
    """Post

     Create a custom email configuration for the organization
    Resource: organization
    Authorized roles: administrator

    Args:
        json_body (EmailConfiguration):

    Returns:
        Response[EmailConfiguration]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    json_body: EmailConfiguration,
) -> Response[EmailConfiguration]:
    """Post

     Create a custom email configuration for the organization
    Resource: organization
    Authorized roles: administrator

    Args:
        json_body (EmailConfiguration):

    Returns:
        Response[EmailConfiguration]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    json_body: EmailConfiguration,
) -> Optional[EmailConfiguration]:
    """Post

     Create a custom email configuration for the organization
    Resource: organization
    Authorized roles: administrator

    Args:
        json_body (EmailConfiguration):

    Returns:
        Response[EmailConfiguration]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed
